package com.xy.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.xy.utils.PageBean;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

@Data
@ApiModel
@Accessors(chain = true)
public class SysDictDto {

    @Data
    @ApiModel
    @Accessors(chain = true)
    public static class Save {

        @ApiModelProperty("父编码")
        private String paterCode;

        @NotBlank(message = "code不能为空")
        @ApiModelProperty("编码")
        private String code;

        @NotBlank(message = "value不能为空")
        @ApiModelProperty("编码值")
        private String value;

        @NotBlank(message = "msg不能为空")
        @ApiModelProperty("编码说明")
        private String msg;
    }

    @Data
    @ApiModel
    @Accessors(chain = true)
    public static class Update extends Save {

        @NotNull(message = "id不能为空")
        @ApiModelProperty("唯一标识")
        private Integer id;

        @ApiModelProperty("状态")
        private Boolean status;
    }

    @Data
    @ApiModel
    @Accessors(chain = true)
    public static class Del {

        @NotEmpty(message = "id不能为空")
        @ApiModelProperty("唯一标识")
        private List<Integer> id;
    }

    @Data
    @ApiModel
    @Accessors(chain = true)
    public static class Page extends Vo {

        private PageBean page;

        @JsonFormat(pattern = "yyyy-MM-dd")
        @ApiModelProperty(value = "创建时间-起")
        private LocalDate beginCreateTime;

        @JsonFormat(pattern = "yyyy-MM-dd")
        @ApiModelProperty(value = "创建时间-始")
        private LocalDate endCreateTime;

        public LocalDateTime getBeginCreateTime() {
            return beginCreateTime == null ? null : beginCreateTime.atTime(0, 0, 0);
        }

        public LocalDateTime getEndCreateTime() {
            return endCreateTime == null ? null : endCreateTime.atTime(23, 59, 59);
        }
    }

    @Data
    @Accessors(chain = true)
    public static class Vo {

        @ApiModelProperty("id")
        private Integer id;

        @ApiModelProperty("父编码")
        private String paterCode;

        @ApiModelProperty("编码")
        private String code;

        @ApiModelProperty("编码值")
        private String value;

        @ApiModelProperty("编码说明")
        private String msg;

        @ApiModelProperty("状态")
        private Boolean status;

        @ApiModelProperty("创建时间")
        @JsonFormat(pattern = "yyyy-MM-dd")
        private LocalDateTime createTime;

        @ApiModelProperty("更新时间")
        @JsonFormat(pattern = "yyyy-MM-dd")
        private LocalDateTime updateTime;

        @ApiModelProperty("创建人")
        private Long createUser;

        @ApiModelProperty("更新人")
        private Long updateUser;
    }

}
